@@ -4,8 +4,8 @@
 """
     PyLucid gallery
     ~~~~~~~~~~~~~~~
-    
-    :copyleft: 2010-2011 by the PyLucid team, see AUTHORS for more details.
+
+    :copyleft: 2010-2012 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
@@ -28,6 +28,9 @@ from django.http import Http404, HttpResponseRedirect, HttpResponseBadRequest
 from django.template.context import RequestContext
 from django.utils.translation import ugettext as _
 
+# TODO: Should be moved to django-tools!
+from pylucid_project.filemanager.filemanager import BaseFilemanager, FilemanagerError
+
 from pylucid_project.apps.pylucid.models import LogEntry
 from pylucid_project.apps.pylucid.shortcuts import render_pylucid_response
 
@@ -42,7 +45,7 @@ def _fnmatch_list(item, filter_list):
     """
     >>> _fnmatch_list("foo.jpg", ["*.bar", "*.jpg"])
     True
-    
+
     >>> _fnmatch_list("foo.jpg", ["*.bar"])
     False
     """
@@ -56,7 +59,7 @@ def _split_suffix(filename, suffix_list):
     """
     >>> _split_suffix("picture_no.jpg", ["_foo","_bar"])
     False
-    
+
     >>> _split_suffix("picture_web.jpg", ["_web"])
     'picture'
     """
@@ -72,100 +75,27 @@ def _split_suffix(filename, suffix_list):
 #------------------------------------------------------------------------------
 
 
-class GalleryError(Exception):
-    """
-    for errors with a message to staff/admin users.
-    e.g.: Gallery filesystem path doesn't exist anymore.
-    """
-    pass
+class Gallery(BaseFilemanager):
+    def __init__(self, config, *args, **kwargs):
+        # use unauthorized signs from preferences
+        pref_form = GalleryPrefForm()
+        preferences = pref_form.get_preferences()
+        unauthorized_signs = preferences["unauthorized_signs"]
+        kwargs["unauthorized_signs"] = unauthorized_signs
 
+        super(Gallery, self).__init__(*args, **kwargs)
+
+        # Galleries are only allowed in STATIC_ROOT
+        self.check_path(settings.STATIC_ROOT, self.abs_path)
 
-class Gallery(object):
-    def __init__(self, request, config, rest_url):
-        self.request = request
-        self.pagetree = self.request.PYLUCID.pagetree
         self.config = config
-
-        self.gallery_base_url = self.request.PYLUCID.pagemeta.get_absolute_url()
-
-        self.rel_path, self.rel_url = self.check_rest_url(rest_url)
-
-        self.rel_base_path = self.config.path
-        self.abs_path = os.path.normpath(os.path.join(settings.STATIC_ROOT, self.rel_base_path, self.rel_path))
-
-        is_dir = os.path.isdir(self.abs_path)
-        is_in_root = self.abs_path.startswith(settings.STATIC_ROOT)
-        if not is_dir or not is_in_root:
-            msg = _("Wrong path.")
-            has_change_perm = request.user.has_perm("gallery.change_gallerymodel")
-            if settings.DEBUG or has_change_perm:
-                msg += " - path %r" % self.abs_path
-                if not is_dir:
-                    msg += " is not a directory."
-                if not is_in_root:
-                    msg += " is not in media root."
-                if has_change_perm: # raise 404 in debug
-                    raise GalleryError(msg)
-            raise Http404(msg)
-
-        self.abs_base_url = posixpath.normpath(posixpath.join(settings.STATIC_URL, self.rel_base_path, self.rel_path))
+        self.static_base_url = posixpath.normpath(posixpath.join(settings.STATIC_URL, config.path, self.rel_url))
 
         dirs, pictures, thumbs = self.read_dir(self.abs_path)
 
         self.dir_info = self.build_dir_info(dirs)
         self.picture_info = self.build_picture_info(pictures, thumbs)
 
-        self.breadcrumbs = self.build_breadcrumbs()
-
-    def build_breadcrumbs(self):
-        parts = ""
-        url = self.gallery_base_url
-        breadcrumbs = [{
-            "name": _("index"),
-            "title": _("goto 'index'"),
-            "url": url
-        }]
-        rel_url = self.rel_url.strip("/")
-        if not rel_url:
-            return breadcrumbs
-
-        for url_part in rel_url.split("/"):
-            url += "%s/" % url_part
-            parts += "%s/" % url_part
-            breadcrumbs.append({
-                "name": url_part,
-                "title": _("goto '%s'") % parts,
-                "url": url
-            })
-        return breadcrumbs
-
-    def make_url(self, part):
-        return posixpath.normpath(posixpath.join(self.abs_base_url, part))
-
-    def check_rest_url(self, rest_url):
-        if rest_url == "":
-            return ("", "")
-
-        pref_form = GalleryPrefForm()
-        preferences = pref_form.get_preferences()
-        unauthorized_signs = preferences["unauthorized_signs"]
-        assert isinstance(unauthorized_signs, (list, tuple))
-        for sign in unauthorized_signs:
-            if sign and sign in rest_url:
-                msg1 = "unauthorized sign"
-                msg = "'%s' in '%s'" % (sign, rest_url)
-                LogEntry.objects.log_action(
-                    app_label="pylucid_plugin.gallery", action=msg1, message=msg
-                )
-                msg404 = "bad path"
-                if settings.DEBUG or self.request.user.is_staff:
-                    msg404 += " - %s: %s" % (msg1, msg)
-                raise Http404(msg404)
-
-        rel_path = os.path.normpath(rest_url)
-        rel_url = posixpath.normpath(rel_path)
-        return rel_path, rel_url
-
     def read_dir(self, path):
         pictures = []
         thumbs = {}
@@ -211,6 +141,9 @@ class Gallery(object):
 
         return dir_info
 
+    def make_url(self, part):
+        return posixpath.normpath(posixpath.join(self.static_base_url, part))
+
     def build_picture_info(self, pictures, thumbs):
         picture_info = []
         for picture in pictures:
@@ -266,11 +199,22 @@ def gallery(request, rest_url=""):
                 parent_url = pagetree.parent.get_absolute_url()
             return HttpResponseRedirect(parent_url)
 
+    rel_base_path = config.path
+    base_url = request.PYLUCID.pagemeta.get_absolute_url()
+    absolute_path = os.path.normpath(os.path.join(settings.STATIC_ROOT, rel_base_path))
+
     try:
-        gallery = Gallery(request, config, rest_url)
-    except GalleryError, err:
-        messages.error(request, "Gallery error: %s" % err)
-        return HttpResponseRedirect(reverse("admin:gallery_gallerymodel_change", args=(config.id,)))
+        gallery = Gallery(config, request, absolute_path, base_url, rest_url)
+    except FilemanagerError, err:
+        has_change_perm = request.user.has_perm("gallery.change_gallerymodel")
+        if settings.DEBUG or has_change_perm:
+            raise
+
+        LogEntry.objects.log_action(
+            app_label="pylucid_plugin.gallery", action="build gallery", message="%s" % err
+        )
+        raise Http404("Gallery error.")
+
 
     if not request.is_ajax():
         # FIXME: In Ajax request, only the page_content would be replaced, not the
